# UA-Email-Client

Provides easy interface for sending emails through Amazons Simple Email Service.

## Motivation

To make a python API that could obfuscate the details of sending emails using AWS SES service.

## Code Example

```python

```

## Installation

pip install --user ua-email-client

## Credits

[RyanJohannesBland](https://github.com/RyanJohannesBland)

## License

MIT
